@@ -21,10 +21,12 @@ from . import *
 from .__version__ import __version__
 from ._base_client import ApiKeyFrom, FromConvertDot, UrHellFrom
 from ._client import RyzenthApiClient
+from ._new_client import RyzenthAuthClient
 
 __all__ = [
   "ApiKeyFrom",
   "RyzenthApiClient",
+  "RyzenthAuthClient",
   "UrHellFrom",
   "FromConvertDot"
 ]
