@@ -1,15 +1,9 @@
+"""API is disabled move to domain new
+
 from Ryzenth import ApiKeyFrom
-from Ryzenth.types import QueryParameter  # disarankan gunakan absolute import
+from Ryzenth.types import QueryParameter
 
 
-def test_send_message():
-    ryz = ApiKeyFrom(..., is_ok=True)
-    result = ryz._sync.send_message(
-        model="hybrid",
-        params=QueryParameter(query="hello world!")
-    )
-    assert result is not None
-
 def test_send_message_melayu():
     ryz = ApiKeyFrom(..., is_ok=True)
     result = ryz._sync.send_message(
@@ -18,3 +12,4 @@ def test_send_message_melayu():
         use_full_model_list=True
     )
     assert result is not None
+"""
